.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2019 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

API Documentation
=================

Crud resource
-------------

.. automodule:: anyblok_pyramid_rest_api.crud_resource
   :members:
   :undoc-members:
   :show-inheritance:

Validator
---------

.. automodule:: anyblok_pyramid_rest_api.validator
   :members:
   :undoc-members:
   :show-inheritance:

Schema
------

.. automodule:: anyblok_pyramid_rest_api.schema
   :members:
   :undoc-members:
   :show-inheritance:

Query string
------------

.. automodule:: anyblok_pyramid_rest_api.querystring
   :members:
   :undoc-members:
   :show-inheritance:

Adapter
-------

.. automodule:: anyblok_pyramid_rest_api.adapter
   :members:
   :undoc-members:
   :show-inheritance:
